@@ -17,13 +17,13 @@ from typing import Any, Dict, List, Type
 from botocore.client import ClientMeta
 
 from .type_defs import (
-    BatchExecuteStatementResponseResponseTypeDef,
-    BeginTransactionResponseResponseTypeDef,
-    CommitTransactionResponseResponseTypeDef,
-    ExecuteSqlResponseResponseTypeDef,
-    ExecuteStatementResponseResponseTypeDef,
+    BatchExecuteStatementResponseTypeDef,
+    BeginTransactionResponseTypeDef,
+    CommitTransactionResponseTypeDef,
+    ExecuteSqlResponseTypeDef,
+    ExecuteStatementResponseTypeDef,
     ResultSetOptionsTypeDef,
-    RollbackTransactionResponseResponseTypeDef,
+    RollbackTransactionResponseTypeDef,
     SqlParameterTypeDef,
 )
 
@@ -50,7 +50,7 @@ class Exceptions:
 
 class RDSDataServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html)
     """
 
@@ -67,21 +67,21 @@ class RDSDataServiceClient:
         parameterSets: List[List["SqlParameterTypeDef"]] = None,
         schema: str = None,
         transactionId: str = None
-    ) -> BatchExecuteStatementResponseResponseTypeDef:
+    ) -> BatchExecuteStatementResponseTypeDef:
         """
         Runs a batch SQL statement over an array of data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#batch_execute_statement)
         """
 
     def begin_transaction(
         self, *, resourceArn: str, secretArn: str, database: str = None, schema: str = None
-    ) -> BeginTransactionResponseResponseTypeDef:
+    ) -> BeginTransactionResponseTypeDef:
         """
         Starts a SQL transaction.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#begin_transaction)
         """
 
@@ -89,18 +89,18 @@ class RDSDataServiceClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#can_paginate)
         """
 
     def commit_transaction(
         self, *, resourceArn: str, secretArn: str, transactionId: str
-    ) -> CommitTransactionResponseResponseTypeDef:
+    ) -> CommitTransactionResponseTypeDef:
         """
         Ends a SQL transaction started with the `BeginTransaction` operation and commits
         the changes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#commit_transaction)
         """
 
@@ -112,11 +112,11 @@ class RDSDataServiceClient:
         sqlStatements: str,
         database: str = None,
         schema: str = None
-    ) -> ExecuteSqlResponseResponseTypeDef:
+    ) -> ExecuteSqlResponseTypeDef:
         """
         Runs one or more SQL statements.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute_sql)
         """
 
@@ -133,11 +133,11 @@ class RDSDataServiceClient:
         resultSetOptions: "ResultSetOptionsTypeDef" = None,
         schema: str = None,
         transactionId: str = None
-    ) -> ExecuteStatementResponseResponseTypeDef:
+    ) -> ExecuteStatementResponseTypeDef:
         """
         Runs a SQL statement against a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute_statement)
         """
 
@@ -151,16 +151,16 @@ class RDSDataServiceClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#generate_presigned_url)
         """
 
     def rollback_transaction(
         self, *, resourceArn: str, secretArn: str, transactionId: str
-    ) -> RollbackTransactionResponseResponseTypeDef:
+    ) -> RollbackTransactionResponseTypeDef:
         """
         Performs a rollback of a transaction.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#rollback_transaction)
         """
